@@ -11,6 +11,7 @@
 #' @param transf Applies data transformation (default is 1; for log consider 0)
 #' @param norm Error normality test (\emph{default} is Shapiro-Wilk)
 #' @param homog Homogeneity test of variances (\emph{default} is Bartlett)
+#' @param homog.value Reference value for homogeneity of experiments. By default, this ratio should not be greater than 7
 #' @param mcomp Multiple comparison test (Tukey (\emph{default}), LSD, Scott-Knott and Duncan)
 #' @param quali Defines whether the factor is quantitative or qualitative (\emph{default} is qualitative)
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
@@ -27,6 +28,7 @@
 #' @param textsize Font size
 #' @param family Font family
 #' @param errorbar Plot the standard deviation bar on the graph (In the case of a segment and column graph) - \emph{default} is TRUE
+#' @note In this function there are three possible outcomes. When the ratio between the experiments is greater than 7, the separate analyzes are returned, without however using the square of the joint residue. When the ratio is less than 7, but with significant interaction, the effects are tested using the square of the joint residual. When there is no significant interaction and the ratio is less than 7, the joint analysis between the experiments is returned.
 #' @note The ordering of the graph is according to the sequence in which the factor levels are arranged in the data sheet. The bars of the column and segment graphs are standard deviation.
 #' @note In the final output when transformation (transf argument) is different from 1, the columns resp and respo in the mean test are returned, indicating transformed and non-transformed mean, respectively.
 #' @return Returns the assumptions of the analysis of variance, the assumption of the joint analysis by means of a QMres ratio matrix, the analysis of variance, the multiple comparison test or regression.
@@ -59,6 +61,7 @@ conjdic=function(trat,
                  norm="sw",
                  homog="bt",
                  mcomp="tukey",
+                 homog.value=7,
                  quali=TRUE,
                  alpha.f=0.05,
                  alpha.t=0.05,
@@ -146,7 +149,7 @@ conjdic=function(trat,
   nexp=length(unique(local))
   ntrat=length(unique(trat))
   nrep=table(trat)/nexp
-  GL=nexp*(ntrat*nrep[1]-(ntrat-1))
+  GL=a$Df[2]#nexp*(ntrat*nrep[1]-(ntrat-1))
   resmed=data.frame(rbind(c(GL,NA,mean(QMRES),NA,NA)))
   colnames(resmed)=colnames(datas)
   datas=rbind(datas,resmed)
@@ -233,7 +236,7 @@ conjdic=function(trat,
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   print(qmresmedio)
   message(blue("\nBased on the analysis of variance and homogeneity of experiments, it can be concluded that: "))
-  if(qmresmedio<7 && a$`Pr(>F)`[1]>alpha.f){
+  if(qmresmedio<homog.value && a$`Pr(>F)`[1]>alpha.f){
     message(black("The experiments can be analyzed together"))}else{
     message("Experiments cannot be analyzed together (Separate by experiment)")}
   cat("\n\n")
@@ -243,18 +246,22 @@ conjdic=function(trat,
   print(as.matrix(datas),na.print = "")
   cat(green(bold("\n-----------------------------------------------------------------\n")))
 
-  if(a$`Pr(>F)`[1] < alpha.f | qmresmedio > 7){
-    if(a$`Pr(>F)`[1] < alpha.f && quali==TRUE | qmresmedio > 7 && quali==TRUE){
+  if(qmresmedio > homog.value){
+    if(a$`Pr(>F)`[1] < alpha.f && quali==TRUE | qmresmedio > homog.value && quali==TRUE){
     for(i in 1:length(levels(local))){
         anova[[i]]=anova(aov(resp~tratamento, data=dados[dados$local==levels(dados$local)[i],]))
         aov1=aov(resp~tratamento, data=dados[dados$local==levels(dados$local)[i],])
+        anova[[i]]=as.matrix(data.frame(anova[[i]]))
+        colnames(anova[[i]])=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
+        rownames(anova[[i]])=c("Trat","Residuals")
+
         if(quali==TRUE){
           if(mcomp=="tukey"){tukey[[i]]=TUKEY(aov1,"tratamento",alpha = alpha.t)$groups
-          comp=TUKEY(aov1,"tratamento")$groups}
+          comp=TUKEY(aov1,"tratamento",alpha = alpha.t)$groups}
           if(mcomp=="duncan"){tukey[[i]]=duncan(aov1,"tratamento",alpha = alpha.t)$groups
-          comp=duncan(aov1,"tratamento")$groups}
+          comp=duncan(aov1,"tratamento",alpha = alpha.t)$groups}
           if(mcomp=="lsd"){tukey[[i]]=LSD(aov1,"tratamento",alpha = alpha.t)$groups
-          comp=LSD(aov1,"tratamento")$groups}
+          comp=LSD(aov1,"tratamento",alpha = alpha.t)$groups}
           if(mcomp=="sk"){
             anova=anova(aov1)
             data=dados[dados$local==levels(dados$local)[i],]
@@ -305,8 +312,16 @@ conjdic=function(trat,
                   axis.text = element_text(size=textsize,color="black", family = family),
                   legend.position = "none")}
         graficos[[i]]=grafico}
+      print(anova,na.print = "")
+      teste=if(mcomp=="tukey"){"Tukey HSD"}else{
+        if(mcomp=="sk"){"Scott-Knott"}else{
+          if(mcomp=="lsd"){"LSD-Fischer"}else{
+            if(mcomp=="duncan"){"Duncan"}}}}
+      cat(green(bold("\n-----------------------------------------------------------------\n")))
+      cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
+      cat(green(bold("-----------------------------------------------------------------\n")))
       print(tukey)}
-    if(a$`Pr(>F)`[1] < alpha.f && quali==FALSE | qmresmedio > 7 && quali==FALSE){
+    if(a$`Pr(>F)`[1] < alpha.f && quali==FALSE | qmresmedio > homog.value && quali==FALSE){
         for(i in 1:length(levels(local))){
         data=dados[dados$local==levels(dados$local)[i],]
         dose1=data$tratnum
@@ -320,10 +335,110 @@ conjdic=function(trat,
                            theme=theme,
                            posi="top",
                            se=errorbar)[[1]]
-        graficos[[i]]=grafico}}
+        graficos[[i]]=grafico[[1]]}}
     }
+  if(a$`Pr(>F)`[1] < alpha.f && qmresmedio < homog.value){
+    GLconj=datas$Df[4]
+    SQconj=datas$`Sum Sq`[4]
+    QMconj=datas$`Mean Sq`[4]
+    if(a$`Pr(>F)`[1] < alpha.f && quali==TRUE | qmresmedio > homog.value && quali==TRUE){
+      for(i in 1:length(levels(local))){
+        anova[[i]]=anova(aov(resp~tratamento, data=dados[dados$local==levels(dados$local)[i],]))
+        anova[[i]][2,]=c(GLconj,SQconj,QMconj,NA,NA)
+        anova[[i]][1,4]=anova[[i]][1,3]/anova[[i]][2,3]
+        anova[[i]][1,5]=1-pf(anova[[i]][1,4],anova[[i]][1,1],anova[[i]][2,1])
+        anova[[i]]=as.matrix(data.frame(anova[[i]]))
+        colnames(anova[[i]])=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
+        rownames(anova[[i]])=c("Trat","Average Residual")
+        trat1=dados[dados$local==levels(dados$local)[i],]$tratamento
+        resp1=dados[dados$local==levels(dados$local)[i],]$resp
+        if(quali==TRUE){
+          if(mcomp=="tukey"){tukey[[i]]=TUKEY(resp1,trat1,DFerror = GLconj,MSerror = QMconj,alpha = alpha.t)$groups
+          comp=TUKEY(resp1,trat1,DFerror = GLconj,MSerror = QMconj,alpha = alpha.t)$groups}
+          if(mcomp=="duncan"){tukey[[i]]=duncan(resp1,trat1,DFerror = GLconj,MSerror = QMconj,alpha = alpha.t)$groups
+          comp=duncan(resp1,trat1,DFerror = GLconj,MSerror = QMconj,alpha = alpha.t)$groups}
+          if(mcomp=="lsd"){tukey[[i]]=LSD(resp1,trat1,DFerror = GLconj,MSerror = QMconj,alpha = alpha.t)$groups
+          comp=LSD(resp1,trat1,DFerror = GLconj,MSerror = QMconj,alpha = alpha.t)$groups}
+          if(mcomp=="sk"){
+            data=dados[dados$local==levels(dados$local)[i],]
+            nrep=table(data$trat)[1]
+            medias=sort(tapply(data$resp,data$trat,mean),decreasing = TRUE)
+            letra=scottknott(means = medias,
+                             df1 = GLconj,
+                             nrep = nrep,
+                             QME = QMconj,
+                             alpha = alpha.t)
+            letra1=data.frame(resp=medias,groups=letra)
+            tukey[[i]]=letra1
+            comp=letra1}
+
+          if(transf=="1"){}else{tukey[[i]]$respo=with(dados[dados$local==levels(dados$local)[i],],
+                                                      tapply(response, tratamento,
+                                                             mean, na.rm=TRUE))[rownames(comp)]}
+          names(tukey)[i]=levels(local)[i]
+
+          dadosm=data.frame(comp,
+                            media=with(dados[dados$local==levels(dados$local)[i],],
+                                       tapply(response, tratamento, mean, na.rm=TRUE))[rownames(comp)],
+                            desvio=with(dados[dados$local==levels(dados$local)[i],],
+                                        tapply(response, tratamento, sd, na.rm=TRUE))[rownames(comp)])
+          dadosm$trats=factor(rownames(dadosm),unique(trat))
+          dadosm$limite=dadosm$media+dadosm$desvio
+          dadosm$letra=paste(format(dadosm$media,digits = dec),dadosm$groups)
+          dadosm=dadosm[unique(as.character(trat)),]
+          media=dadosm$media
+          desvio=dadosm$desvio
+          limite=dadosm$limite
+          trats=dadosm$trats
+          letra=dadosm$letra
+          grafico=ggplot(dadosm,
+                         aes(x=trats,
+                             y=media))+
+            geom_col(aes(fill=trats),fill=fill,color=1)+
+            theme_classic()+
+            ylab(ylab)+
+            xlab(xlab)+ylim(0,1.5*max(limite))+
+            geom_errorbar(aes(ymin=media-desvio,
+                              ymax=media+desvio),
+                          color="black",width=0.3)+
+            geom_text(aes(y=media+desvio+sup,
+                          label=letra))+
+            theme(text = element_text(size=textsize,color="black", family = family),
+                  axis.title = element_text(size=textsize,color="black", family = family),
+                  axis.text = element_text(size=textsize,color="black", family = family),
+                  legend.position = "none")}
+        graficos[[i]]=grafico}
+      print(anova,na.print = "")
+      teste=if(mcomp=="tukey"){"Tukey HSD"}else{
+        if(mcomp=="sk"){"Scott-Knott"}else{
+          if(mcomp=="lsd"){"LSD-Fischer"}else{
+            if(mcomp=="duncan"){"Duncan"}}}}
+      cat(green(bold("\n-----------------------------------------------------------------\n")))
+      cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
+      cat(green(bold("-----------------------------------------------------------------\n")))
+      print(tukey)}
+    if(a$`Pr(>F)`[1] < alpha.f && quali==FALSE | qmresmedio > homog.value && quali==FALSE){
+      for(i in 1:length(levels(local))){
+        data=dados[dados$local==levels(dados$local)[i],]
+        dose1=data$tratnum
+        resp=data$response
+        grafico=polynomial(dose1,
+                           resp,grau = grau,
+                           textsize=textsize,
+                           family=family,
+                           ylab=ylab,
+                           xlab=xlab,
+                           theme=theme,SSq = SQconj,
+                           DFres = GLconj,
+                           posi="top",
+                           se=errorbar)[[1]]
+        graficos[[i]]=grafico[[1]]}}
+  }
+  if(a$`Pr(>F)`[1] > alpha.f && qmresmedio < homog.value){
+    GLconj=datas$Df[4]
+    SQconj=datas$`Sum Sq`[4]
+    QMconj=datas$`Mean Sq`[4]
 
-  if(a$`Pr(>F)`[1] > alpha.f && qmresmedio < 7){
     if(quali==TRUE){
     if(mcomp=="tukey"){
       tukeyjuntos=TUKEY(resp,tratamento,a$Df[1], a$`Mean Sq`[1], alpha = alpha.t)
@@ -388,8 +503,13 @@ conjdic=function(trat,
             axis.title = element_text(size=textsize,color="black",family=family),
             legend.position = "none")
     if(angulo !=0){grafico1=grafico1+theme(axis.text.x=element_text(hjust = 1.01,angle = angulo))}
-    cat("Multiple comparison test (",mcomp,")")
-    cat(green(bold("\n-----------------------------------------------------------------\n")))
+    teste=if(mcomp=="tukey"){"Tukey HSD"}else{
+      if(mcomp=="sk"){"Scott-Knott"}else{
+        if(mcomp=="lsd"){"LSD-Fischer"}else{
+          if(mcomp=="duncan"){"Duncan"}}}}
+    cat(green(italic(paste("Multiple Comparison Test:",teste,"\n"))))
+
+    cat(green(bold("-----------------------------------------------------------------\n")))
     print(tukeyjuntos)
     print(grafico1)
     graficos=list(grafico1)
@@ -401,16 +521,18 @@ conjdic=function(trat,
                            ylab=ylab,
                            xlab=xlab,
                            theme=theme,
+                           SSq = SQconj,
+                           DFres = GLconj,
                            posi="top",
                            se=errorbar)
     }
-    graficos=list(grafico1)
+    graficos=list(grafico1[[1]])
 
     }
   cat(if(transf=="1"){}else{blue("\nNOTE: resp = transformed means; respO = averages without transforming\n")})
 
   if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test and try to transform the data"))}
   if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test"))}
-  print(graficos)
+  # print(graficos)
   graph=as.list(graficos)
 }
